@@ -38,7 +38,7 @@
 ##
 ## Sets the PNG output device with a resolution of 300 dpi.
 ##
-## Sample rate of ir1 and ir2 *must* be 44.1 KHz
+## Sample rate of ir1 and ir2 *must* be 44.1 kHz
 ##
 
 function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fdevice = '-depsc')
@@ -289,16 +289,16 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	clear ir1os ir2os ir1osh ir2osh rfl rcf rat;
 
 	# Report the stage
-	disp("Time response, 2 KHz brickwall...");
+	disp("Time response, 2 kHz brickwall...");
 	fflush(stdout);
 	
-	# Create the 2 KHz brickwall filter
+	# Create the 2 kHz brickwall filter
 	fltlen = 4096;
 	fltatt = 160;
 	flt = lowpassfir(fltlen,2000/(fs/2)) .* chebwin(fltlen,fltatt)';
 	fltdelay = (1 + length(flt)) / 2;
 	
-	# Creates the 2 KHz brickwall filtered impulse responses
+	# Creates the 2 kHz brickwall filtered impulse responses
 	# about -20 to +50 ms
 	ir1bw = fftconv(flt,ir1([ic1-882:ic1+2205]));
 	ir2bw = fftconv(flt,ir2([ic2-882:ic2+2205]));
@@ -342,7 +342,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis(gax);
 	
 	# Print to the output file
-	print([ outdir fprefix "-IR2KHzBrickwall" fext ],fdevice);
+	print([ outdir fprefix "-IR2kHzBrickwall" fext ],fdevice);
 	
 	# Computes the analytical signal
 	ir1bwh = abs(hilbert(ir1bw));
@@ -387,7 +387,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis(gax);
 	
 	# Print to the output file
-	print([ outdir fprefix "-IR2KHzBrickwallEnvelope" fext ],fdevice);
+	print([ outdir fprefix "-IR2kHzBrickwallEnvelope" fext ],fdevice);
 	
 	# Open a new plot
 	newplot();
@@ -428,7 +428,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis(gax);
 	
 	# Print to the output file
-	print([ outdir fprefix "-IR2KHzBrickwallETC" fext ],fdevice);
+	print([ outdir fprefix "-IR2kHzBrickwallETC" fext ],fdevice);
 	
 	# Remove variables no longer used
 	clear ir1bw ir2bw ir1bwh ir2bwh;
@@ -608,7 +608,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	semilogx(0.001 * fs * ixg / length(ir1w),20 * log10(abs(ir1w(1 + ixg))),["1;" it1 ";"],"LineWidth",DLW);
 	axis([1, 20]);
 	grid("on");
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Amplitude (dB)");
 	safetics("x",[1,1.5,2,3,5,7,10,16,20]);
 		
@@ -620,7 +620,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	semilogx(0.001 * fs * ixg / length(ir2w),20 * log10(abs(ir2w(1 + ixg))),["3;" it2 ";"],"LineWidth",DLW);
 	axis([1, 20]);
 	grid("on");
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Amplitude (dB)");	
 	safetics("x",[1,1.5,2,3,5,7,10,16,20]);
 	
@@ -663,7 +663,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	semilogx(0.001 * fs * ixg / length(ir1w),180 * angle(ir1w(1 + ixg))/pi,["1;" it1 ";"],"LineWidth",DLW);
 	axis([1, 20, -180, 180]);
 	grid("on");
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Phase (deg)");	
 	safetics("x",[1,1.5,2,3,5,7,10,16,20]);
 	safetics("y",-180:30:180);
@@ -673,7 +673,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	semilogx(0.001 * fs * ixg / length(ir2w),180 * angle(ir2w(1 + ixg))/pi,["3;" it2 ";"],"LineWidth",DLW);
 	axis([1, 20, -180, 180]);
 	grid("on");
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Phase (deg)");	
 	safetics("x",[1,1.5,2,3,5,7,10,16,20]);
 	safetics("y",-180:30:180);
@@ -711,7 +711,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	semilogx(0.001 * fs * ixg / length(ir1w),20 * log10(abs(ir1w(1 + ixg))),["1;" it1 ";"],"LineWidth",DLW);
 	axis([0.2, 20]);
 	grid("on");
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Amplitude (dB)");	
 	safetics("x",[0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
 	safetics("y",-15:3:15);
@@ -724,7 +724,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	semilogx(0.001 * fs * ixg / length(ir2w),20 * log10(abs(ir2w(1 + ixg))),["3;" it2 ";"],"LineWidth",DLW);
 	axis([0.2, 20]);
 	grid("on");
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Amplitude (dB)");	
 	safetics("x",[0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
 	safetics("y",-15:3:15);
@@ -768,7 +768,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	semilogx(0.001 * fs * ixg / length(ir1w),180 * angle(ir1w(1 + ixg))/pi,["1;" it1 ";"],"LineWidth",DLW);
 	axis([0.2, 20, -180, 180]);
 	grid("on");
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Phase (deg)");	
 	safetics("x",[0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
 	safetics("y",-180:30:180);
@@ -778,7 +778,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	semilogx(0.001 * fs * ixg / length(ir2w),180 * angle(ir2w(1 + ixg))/pi,["3;" it2 ";"],"LineWidth",DLW);
 	axis([0.2, 20, -180, 180]);
 	grid("on");
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Phase (deg)");	
 	safetics("x",[0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
 	safetics("y",-180:30:180);
@@ -932,7 +932,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	semilogx(0.001 * fs * ixg / length(ir1w),20 * log10(ir1m(1 + ixg)),["1;" it1 ";"],"LineWidth",DLW);
 	axis([0.02, 20]);
 	grid("on");
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Magnitude (dB)");	
 	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
 	
@@ -944,7 +944,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	semilogx(0.001 * fs * ixg / length(ir2w),20 * log10(ir2m(1 + ixg)),["3;" it2 ";"],"LineWidth",DLW);
 	axis([0.02, 20]);
 	grid("on");
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Magnitude (dB)");	
 	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
 	
@@ -1008,7 +1008,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	semilogx(0.001 * fs * ixg / length(ir1w),180 * angle(ir1w(1 + ixg))/pi,["1;" it1 ";"],"LineWidth",DLW);
 	axis([0.02, 20, -180, 180]);
 	grid("on");
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Phase (deg)");	
 	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
 	safetics("y",-180:30:180);
@@ -1018,7 +1018,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	semilogx(0.001 * fs * ixg / length(ir2w),180 * angle(ir2w(ixg))/pi,["3;" it2 ";"],"LineWidth",DLW);
 	axis([0.02, 20, -180, 180]);
 	grid("on");
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Phase (deg)");	
 	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
 	safetics("y",-180:30:180);
@@ -1066,7 +1066,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	semilogx(0.001 * fs * ixg / length(ir1w),20 * log10(ir1m(1 + ixg)),["1;" it1 ";"],"LineWidth",DLW);
 	axis([0.02, 20]);
 	grid("on");
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Magnitude (dB)");	
 	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
 	
@@ -1078,7 +1078,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	semilogx(0.001 * fs * ixg / length(ir2w),20 * log10(ir2m(1 + ixg)),["3;" it2 ";"],"LineWidth",DLW);
 	axis([0.02, 20]);
 	grid("on");
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Magnitude (dB)");	
 	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
 	
@@ -1142,7 +1142,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	semilogx(0.001 * fs * ixg / length(ir1w),180 * angle(ir1w(1 + ixg))/pi,["1;" it1 ";"],"LineWidth",DLW);
 	axis([0.02, 20, -180, 180]);
 	grid("on");
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Phase (deg)");	
 	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
 	safetics("y",-180:30:180);
@@ -1152,7 +1152,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	semilogx(0.001 * fs * ixg / length(ir2w),180 * angle(ir2w(1 + ixg))/pi,["3;" it2 ";"],"LineWidth",DLW);
 	axis([0.02, 20, -180, 180]);
 	grid("on");
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Phase (deg)");	
 	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
 	safetics("y",-180:30:180);
@@ -1200,7 +1200,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	semilogx(0.001 * fs * ixg / length(ir1w),20 * log10(ir1m(1 + ixg)),["1;" it1 ";"],"LineWidth",DLW);
 	axis([0.02, 20]);
 	grid("on");
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Magnitude (dB)");	
 	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
 	
@@ -1212,7 +1212,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	semilogx(0.001 * fs * ixg / length(ir2w),20 * log10(ir2m(1 + ixg)),["3;" it2 ";"],"LineWidth",DLW);
 	axis([0.02, 20]);
 	grid("on");
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Magnitude (dB)");	
 	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
 	
@@ -1276,7 +1276,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	semilogx(0.001 * fs * ixg / length(ir1w),180 * angle(ir1w(1 + ixg))/pi,["1;" it1 ";"],"LineWidth",DLW);
 	axis([0.02, 20, -180, 180]);
 	grid("on");
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Phase (deg)");	
 	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
 	safetics("y",-180:30:180);
@@ -1286,7 +1286,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	semilogx(0.001 * fs * ixg / length(ir2w),180 * angle(ir2w(1 + ixg))/pi,["3;" it2 ";"],"LineWidth",DLW);
 	axis([0.02, 20, -180, 180]);
 	grid("on");
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Phase (deg)");	
 	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
 	safetics("y",-180:30:180);
@@ -1370,7 +1370,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	subplot(2,1,1);
 	hold("off");
 	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Magnitude (dB)");
 	grid("on");
 	legend(3);
@@ -1378,7 +1378,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	subplot(2,1,2);
 	hold("off");
 	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Magnitude (dB)");
 	grid("on");
 	legend(3);
@@ -1493,7 +1493,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	subplot(2,1,1);
 	hold("off");
 	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Magnitude (dB)");
 	grid("on");
 	legend(3);
@@ -1501,7 +1501,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	subplot(2,1,2);
 	hold("off");
 	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Magnitude (dB)");
 	grid("on");
 	legend(3);
@@ -1591,7 +1591,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 2, 20, -33, 1]);
 	grid("on");
 	xlabel("Time (ms)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
 	safetics("y",[2,5,8,12,16,20]);
 	safetics("z",-30:6:0);
@@ -1612,7 +1612,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 2, 20, -33, 1]);
 	grid("on");
 	xlabel("Time (ms)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
 	safetics("y",[2,5,8,12,16,20]);
 	safetics("z",-30:6:0);
@@ -1643,7 +1643,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 2, 20, -33, 1]);
 	grid("on");
 	xlabel("Time (ms)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
 	safetics("y",[2,5,8,12,16,20]);
 	safetics("z",-30:6:0);
@@ -1664,7 +1664,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 2, 20, -33, 1]);
 	grid("on");
 	xlabel("Time (ms)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
 	safetics("y",[2,5,8,12,16,20]);
 	safetics("z",-30:6:0);
@@ -1726,7 +1726,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 0.2, 2, -33, 1]);
 	grid("on");
 	xlabel("Time (ms)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
 	safetics("y",[0.2,0.5,0.8,1.2,1.6,2.0]);
 	safetics("z",-30:6:0);
@@ -1747,7 +1747,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 0.2, 2, -33, 1]);
 	grid("on");
 	xlabel("Time (ms)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
 	safetics("y",[0.2,0.5,0.8,1.2,1.6,2.0]);
 	safetics("z",-30:6:0);
@@ -1778,7 +1778,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 0.2, 2, -33, 1]);
 	grid("on");
 	xlabel("Time (ms)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
 	safetics("y",[0.2,0.5,0.8,1.2,1.6,2.0]);
 	safetics("z",-30:6:0);
@@ -1799,7 +1799,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 0.2, 2, -33, 1]);
 	grid("on");
 	xlabel("Time (ms)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
 	safetics("y",[0.2,0.5,0.8,1.2,1.6,2.0]);
 	safetics("z",-30:6:0);
@@ -2004,7 +2004,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 2, 20, -33, 1]);
 	grid("on");
 	xlabel("Time (ms)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
 	safetics("y",[2,5,8,12,16,20]);
 	safetics("z",-30:6:0);
@@ -2025,7 +2025,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 2, 20, -33, 1]);
 	grid("on");
 	xlabel("Time (ms)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
 	safetics("y",[2,5,8,12,16,20]);
 	safetics("z",-30:6:0);
@@ -2056,7 +2056,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 2, 20, -33, 1]);
 	grid("on");
 	xlabel("Time (ms)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
 	safetics("y",[2,5,8,12,16,20]);
 	safetics("z",-30:6:0);
@@ -2077,7 +2077,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 2, 20, -33, 1]);
 	grid("on");
 	xlabel("Time (ms)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
 	safetics("y",[2,5,8,12,16,20]);
 	safetics("z",-30:6:0);
@@ -2139,7 +2139,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 0.2, 2, -33, 1]);
 	grid("on");
 	xlabel("Time (ms)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
 	safetics("y",[0.2,0.5,0.8,1.2,1.6,2.0]);
 	safetics("z",-30:6:0);
@@ -2160,7 +2160,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 0.2, 2, -33, 1]);
 	grid("on");
 	xlabel("Time (ms)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
 	safetics("y",[0.2,0.5,0.8,1.2,1.6,2.0]);
 	safetics("z",-30:6:0);
@@ -2191,7 +2191,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 0.2, 2, -33, 1]);
 	grid("on");
 	xlabel("Time (ms)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
 	safetics("y",[0.2,0.5,0.8,1.2,1.6,2.0]);
 	safetics("z",-30:6:0);
@@ -2212,7 +2212,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 0.2, 2, -33, 1]);
 	grid("on");
 	xlabel("Time (ms)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
 	safetics("y",[0.2,0.5,0.8,1.2,1.6,2.0]);
 	safetics("z",-30:6:0);
@@ -2417,7 +2417,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 0, fs / 2000]);
 	grid("on");	
 	xlabel("Time (ms)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
 	text(1.1 * tbe,fs / 4000,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center");
 	colormap(EDCMap);	
@@ -2431,7 +2431,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 0, fs / 2000]);
 	grid("on");	
 	xlabel("Time (ms)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
 	text(1.1 * tbe,fs / 4000,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center");
 	colormap(EDCMap);	
@@ -2488,7 +2488,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 0, fs / 2000]);
 	grid("on");	
 	xlabel("Time (ms)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
 	text(1.1 * tbe,fs / 4000,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center");
 	colormap(EDCMap);	
@@ -2502,7 +2502,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 0, fs / 2000]);
 	grid("on");	
 	xlabel("Time (ms)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
 	text(1.1 * tbe,fs / 4000,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center");
 	colormap(EDCMap);	
@@ -2523,7 +2523,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	fflush(stdout);
 	
 	# Morlet scalogram from -10 cicles to +20 cycles
-	# 20 Hz to 20 KHz
+	# 20 Hz to 20 kHz
 	# 100 frequency points and 350 cicle points
 	cecb = -10;
 	cece = 20;
@@ -2607,7 +2607,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([cecb, cece, cesf / 1000, ceef / 1000, 0, 1]);
 	grid("on");
 	xlabel("Time (cycles)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (norm.)");	
 	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
 	safetics("z",[0.25,0.5,0.75,1.0]);
@@ -2629,7 +2629,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([cecb, cece, cesf / 1000, ceef / 1000, 0, 1]);
 	grid("on");
 	xlabel("Time (cycles)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (norm.)");	
 	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
 	safetics("z",[0.25,0.5,0.75,1.0]);
@@ -2661,7 +2661,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([cecb, cece, cesf / 1000, ceef / 1000, 0, 1]);
 	grid("on");
 	xlabel("Time (cycles)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (norm.)");	
 	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
 	safetics("z",[0.25,0.5,0.75,1.0]);
@@ -2683,7 +2683,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([cecb, cece, cesf / 1000, ceef / 1000, 0, 1]);
 	grid("on");
 	xlabel("Time (cycles)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (norm.)");	
 	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
 	safetics("z",[0.25,0.5,0.75,1.0]);
@@ -2718,7 +2718,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([cecb, cece, 0, rcenf-1]);
 	grid("on");	
 	xlabel("Time (cycles)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (norm)");
 	text(1.1 * cece,rcenf / 2,"Mag. (norm)","Rotation",90,"HorizontalAlignment","center");
 	safetics("y",linspace(0,rcenf-1,10),["0.02";"0.05";"0.1";"0.2";"0.5";"1";"2";"5";"10";"20"]);
@@ -2734,7 +2734,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([cecb, cece, 0, rcenf-1]);
 	grid("on");	
 	xlabel("Time (cycles)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (norm)");
 	text(1.1 * cece,rcenf / 2,"Mag. (norm)","Rotation",90,"HorizontalAlignment","center");
 	safetics("y",linspace(0,rcenf-1,10),["0.02";"0.05";"0.1";"0.2";"0.5";"1";"2";"5";"10";"20"]);
@@ -2767,7 +2767,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([cecb, cece, cesf / 1000, ceef / 1000, -30, 2]);
 	grid("on");
 	xlabel("Time (cycles)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
 	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
 	safetics("z",-25:5:5);
@@ -2789,7 +2789,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([cecb, cece, cesf / 1000, ceef / 1000, -30, 2]);
 	grid("on");
 	xlabel("Time (cycles)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
 	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
 	safetics("z",-25:5:5);
@@ -2821,7 +2821,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([cecb, cece, cesf / 1000, ceef / 1000, -30, 2]);
 	grid("on");
 	xlabel("Time (cycles)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
 	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
 	safetics("z",-25:5:5);
@@ -2843,7 +2843,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([cecb, cece, cesf / 1000, ceef / 1000, -30, 2]);
 	grid("on");
 	xlabel("Time (cycles)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
 	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
 	safetics("z",-25:5:5);
@@ -2878,7 +2878,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([cecb, cece, 0, rcenf-1]);
 	grid("on");	
 	xlabel("Time (cycles)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
 	text(1.1 * cece,rcenf / 2,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center");
 	safetics("y",linspace(0,rcenf-1,10),["0.02";"0.05";"0.1";"0.2";"0.5";"1";"2";"5";"10";"20"]);
@@ -2894,7 +2894,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([cecb, cece, 0, rcenf-1]);
 	grid("on");	
 	xlabel("Time (cycles)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
 	text(1.1 * cece,rcenf / 2,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center");
 	safetics("y",linspace(0,rcenf-1,10),["0.02";"0.05";"0.1";"0.2";"0.5";"1";"2";"5";"10";"20"]);	
@@ -2917,7 +2917,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	fflush(stdout);
 	
 	# Morlet cycle/octave scalogram from -10 cicles to +20 cicles
-	# 20 Hz to 20 KHz
+	# 20 Hz to 20 kHz
 	# 100 frequency points and 350 cicle points
 	cecb = -10;
 	cece = 20;
@@ -3004,7 +3004,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([cecb, cece, cesf / 1000, ceef / 1000, 0, 1]);
 	grid("on");
 	xlabel("Time (cycles)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (norm.)");	
 	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
 	safetics("z",[0.25,0.5,0.75,1.0]);
@@ -3026,7 +3026,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([cecb, cece, cesf / 1000, ceef / 1000, 0, 1]);
 	grid("on");
 	xlabel("Time (cycles)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (norm.)");	
 	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
 	safetics("z",[0.25,0.5,0.75,1.0]);
@@ -3058,7 +3058,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([cecb, cece, cesf / 1000, ceef / 1000, 0, 1]);
 	grid("on");
 	xlabel("Time (cycles)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (norm.)");	
 	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
 	safetics("z",[0.25,0.5,0.75,1.0]);
@@ -3080,7 +3080,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([cecb, cece, cesf / 1000, ceef / 1000, 0, 1]);
 	grid("on");
 	xlabel("Time (cycles)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (norm.)");	
 	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
 	safetics("z",[0.25,0.5,0.75,1.0]);
@@ -3115,7 +3115,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([cecb, cece, 0, rcenf-1]);
 	grid("on");	
 	xlabel("Time (cycles)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (norm)");	
 	text(1.1 * cece,rcenf / 2,"Mag. (norm)","Rotation",90,"HorizontalAlignment","center");
 	safetics("y",linspace(0,rcenf-1,10),["0.02";"0.05";"0.1";"0.2";"0.5";"1";"2";"5";"10";"20"]);	
@@ -3131,7 +3131,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([cecb, cece, 0, rcenf-1]);
 	grid("on");	
 	xlabel("Time (cycles)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (norm)");	
 	text(1.1 * cece,rcenf / 2,"Mag. (norm)","Rotation",90,"HorizontalAlignment","center");
 	safetics("y",linspace(0,rcenf-1,10),["0.02";"0.05";"0.1";"0.2";"0.5";"1";"2";"5";"10";"20"]);	
@@ -3164,7 +3164,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([cecb, cece, cesf / 1000, ceef / 1000, -30, 2]);
 	grid("on");
 	xlabel("Time (cycles)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
 	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
 	safetics("z",-25:5:5);
@@ -3186,7 +3186,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([cecb, cece, cesf / 1000, ceef / 1000, -30, 2]);
 	grid("on");
 	xlabel("Time (cycles)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
 	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
 	safetics("z",-25:5:5);
@@ -3218,7 +3218,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([cecb, cece, cesf / 1000, ceef / 1000, -30, 2]);
 	grid("on");
 	xlabel("Time (cycles)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
 	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
 	safetics("z",-25:5:5);
@@ -3240,7 +3240,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([cecb, cece, cesf / 1000, ceef / 1000, -30, 2]);
 	grid("on");
 	xlabel("Time (cycles)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
 	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
 	safetics("z",-25:5:5);
@@ -3275,7 +3275,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([cecb, cece, 0, rcenf-1]);
 	grid("on");	
 	xlabel("Time (cycles)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
 	text(1.1 * cece,rcenf / 2,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center");
 	safetics("y",linspace(0,rcenf-1,10),["0.02";"0.05";"0.1";"0.2";"0.5";"1";"2";"5";"10";"20"]);	
@@ -3291,7 +3291,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([cecb, cece, 0, rcenf-1]);
 	grid("on");	
 	xlabel("Time (cycles)");
-	ylabel("Frequency (KHz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
 	text(1.1 * cece,rcenf / 2,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center");
 	safetics("y",linspace(0,rcenf-1,10),["0.02";"0.05";"0.1";"0.2";"0.5";"1";"2";"5";"10";"20"]);	
