@@ -59,7 +59,7 @@
 #include <fenv.h>
 
 /* Versione corrente */
-#define DRCVersion "3.1.1"
+#define DRCVersion "3.2.0"
 #define DRCCopyright "2002-2011"
 
 /* Header iniziale programma */
@@ -670,7 +670,7 @@ int main(int argc, char * argv[])
 
     /* Calcola il valore RMS del segnale in ingresso */
 		SRMSValue = GetRMSLevel(OInSig,MCOutSigLen);
-		if (SRMSValue > 0)
+		if (SRMSValue > ((DLReal) 0.0))
 			printf("Input signal RMS level %f (%f dB).\n",(double) SRMSValue, (double) (20 * log10((double) SRMSValue)));
 		else
 			printf("Input signal RMS level %f (-Inf dB).\n",(double) SRMSValue);
@@ -687,9 +687,10 @@ int main(int argc, char * argv[])
 					{
 						/* Fase lineare */
 						case 'L':
+						case 'P':
 							sputs("Input signal linear phase dip limiting...");
 							if (C1LPDipLimit(&MCOutSig[MCOutSigStart],MCOutSigLen,Cfg.BCDLMinGain,Cfg.BCDLStart,
-								Cfg.BCSampleRate,Cfg.BCDLStartFreq,Cfg.BCDLEndFreq,Cfg.BCDLMultExponent) == False)
+								Cfg.BCSampleRate,Cfg.BCDLStartFreq,Cfg.BCDLEndFreq,Cfg.BCDLType[0] == 'P',Cfg.BCDLMultExponent) == False)
 								{
 									sputs("Dip limiting failed.");
 									return 1;
@@ -698,9 +699,10 @@ int main(int argc, char * argv[])
 
 						/* Fase minima */
 						case 'M':
+						case 'W':
 							sputs("Input signal minimum phase dip limiting...");
 							if (C1HMPDipLimit(&MCOutSig[MCOutSigStart],MCOutSigLen,Cfg.BCDLMinGain,Cfg.BCDLStart,
-								Cfg.BCSampleRate,Cfg.BCDLStartFreq,Cfg.BCDLEndFreq,Cfg.BCDLMultExponent) == False)
+								Cfg.BCSampleRate,Cfg.BCDLStartFreq,Cfg.BCDLEndFreq,Cfg.BCDLType[0] == 'W',Cfg.BCDLMultExponent) == False)
 								{
 									sputs("Dip limiting failed.");
 									return 1;
@@ -923,9 +925,10 @@ int main(int argc, char * argv[])
 					{
 						/* Fase lineare */
 						case 'L':
+						case 'P':
 							sputs("MP signal linear phase dip limiting...");
 							if (C1LPDipLimit(&MPPFSig[WStart1],WLen1,Cfg.DLMinGain,Cfg.DLStart,
-								Cfg.BCSampleRate,Cfg.DLStartFreq,Cfg.DLEndFreq,Cfg.DLMultExponent) == False)
+								Cfg.BCSampleRate,Cfg.DLStartFreq,Cfg.DLEndFreq,Cfg.DLType[0] == 'P',Cfg.DLMultExponent) == False)
 								{
 									sputs("Dip limiting failed.");
 									return 1;
@@ -934,9 +937,10 @@ int main(int argc, char * argv[])
 
 						/* Fase minima */
 						case 'M':
+						case 'W':
 							sputs("MP signal minimum phase dip limiting...");
 							if (C1HMPDipLimit(&MPPFSig[WStart1],WLen1,Cfg.DLMinGain,Cfg.DLStart,
-								Cfg.BCSampleRate,Cfg.DLStartFreq,Cfg.DLEndFreq,Cfg.DLMultExponent) == False)
+								Cfg.BCSampleRate,Cfg.DLStartFreq,Cfg.DLEndFreq,Cfg.DLType[0] == 'W',Cfg.DLMultExponent) == False)
 								{
 									sputs("Dip limiting failed.");
 									return 1;
@@ -1547,9 +1551,10 @@ int main(int argc, char * argv[])
 							{
 								/* Fase lineare */
 								case 'L':
+								case 'P':
 									sputs("Target reference signal linear phase dip limiting...");
 									if (C1LPDipLimit(&PTTConv[PTTRefLen],Cfg.PTReferenceWindow,Cfg.PTDLMinGain,Cfg.PTDLStart,
-										Cfg.BCSampleRate,Cfg.PTDLStartFreq,Cfg.PTDLEndFreq,Cfg.PTDLMultExponent) == False)
+										Cfg.BCSampleRate,Cfg.PTDLStartFreq,Cfg.PTDLEndFreq,Cfg.PTDLType[0] == 'P',Cfg.PTDLMultExponent) == False)
 										{
 											sputs("Dip limiting failed.");
 											return 1;
@@ -1558,9 +1563,10 @@ int main(int argc, char * argv[])
 
 								/* Fase minima */
 								case 'M':
+								case 'W':
 									sputs("Target reference minimum phase dip limiting...");
 									if (C1HMPDipLimit(&PTTConv[PTTRefLen],Cfg.PTReferenceWindow,Cfg.PTDLMinGain,Cfg.PTDLStart,
-										Cfg.BCSampleRate,Cfg.PTDLStartFreq,Cfg.PTDLEndFreq,Cfg.PTDLMultExponent) == False)
+										Cfg.BCSampleRate,Cfg.PTDLStartFreq,Cfg.PTDLEndFreq,Cfg.PTDLType[0] == 'W',Cfg.PTDLMultExponent) == False)
 										{
 											sputs("Dip limiting failed.");
 											return 1;
@@ -1721,9 +1727,10 @@ int main(int argc, char * argv[])
 					{
 						/* Fase lineare */
 						case 'L':
+						case 'P':
 							sputs("Linear phase peak limiting...");
 							if (C1LPPeakLimit(&ISRevOut[WStart2],WLen2,Cfg.PLMaxGain,Cfg.PLStart,
-								Cfg.BCSampleRate,Cfg.PLStartFreq,Cfg.PLEndFreq,Cfg.PLMultExponent) == False)
+								Cfg.BCSampleRate,Cfg.PLStartFreq,Cfg.PLEndFreq,Cfg.PLType[0] == 'P',Cfg.PLMultExponent) == False)
 								{
 									sputs("Peak limiting failed.");
 									return 1;
@@ -1732,9 +1739,10 @@ int main(int argc, char * argv[])
 
 						/* Fase minima */
 						case 'M':
+						case 'W':
 							sputs("Minimum phase peak limiting...");
 							if (C1HMPPeakLimit(&ISRevOut[WStart2],WLen2,Cfg.PLMaxGain,Cfg.PLStart,
-								Cfg.BCSampleRate,Cfg.PLStartFreq,Cfg.PLEndFreq,Cfg.PLMultExponent) == False)
+								Cfg.BCSampleRate,Cfg.PLStartFreq,Cfg.PLEndFreq,Cfg.PLType[0] == 'W',Cfg.PLMultExponent) == False)
 								{
 									sputs("Peak limiting failed.");
 									return 1;
