@@ -534,7 +534,8 @@ int CheckDRCCfg(const CfgParmsType * DRCCfg)
 				sputs("BC->BCDLType: No BCDLType supplied.");
 				return 1;
 			}
-		if (DRCCfg->BCDLType[0] != 'L' && DRCCfg->BCDLType[0] != 'M')
+		if (DRCCfg->BCDLType[0] != 'L' && DRCCfg->BCDLType[0] != 'M'
+				&& DRCCfg->BCDLType[0] != 'P' && DRCCfg->BCDLType[0] != 'W')
 			{
 				sputs("BC->BCDLType: Invalid dip limiting type supplied.");
 				return 1;
@@ -670,7 +671,8 @@ int CheckDRCCfg(const CfgParmsType * DRCCfg)
 				sputs("DL->DLType: No DLType supplied.");
 				return 1;
 			}
-		if (DRCCfg->DLType[0] != 'L' && DRCCfg->DLType[0] != 'M')
+		if (DRCCfg->DLType[0] != 'L' && DRCCfg->DLType[0] != 'M'
+				&& DRCCfg->DLType[0] != 'P' && DRCCfg->DLType[0] != 'W')
 			{
 				sputs("DL->DLType: Invalid dip limiting type supplied.");
 				return 1;
@@ -887,7 +889,8 @@ int CheckDRCCfg(const CfgParmsType * DRCCfg)
 						sputs("PT->PTDLType: No DLType supplied.");
 						return 1;
 					}
-				if (DRCCfg->PTDLType[0] != 'L' && DRCCfg->PTDLType[0] != 'M')
+				if (DRCCfg->PTDLType[0] != 'L' && DRCCfg->PTDLType[0] != 'M'
+						&& DRCCfg->PTDLType[0] != 'P' && DRCCfg->PTDLType[0] != 'W')
 					{
 						sputs("PT->PTDLType: Invalid dip limiting type supplied.");
 						return 1;
@@ -977,7 +980,8 @@ int CheckDRCCfg(const CfgParmsType * DRCCfg)
 				sputs("PL->PLType: No peak limiting type supplied.");
 				return 1;
 			}
-		if (DRCCfg->PLType[0] != 'L' && DRCCfg->PLType[0] != 'M')
+		if (DRCCfg->PLType[0] != 'L' && DRCCfg->PLType[0] != 'M'
+				&& DRCCfg->PLType[0] != 'P' && DRCCfg->PLType[0] != 'W')
 			{
 				sputs("PL->PLType: Invalid peak limiting type supplied.");
 				return 1;
