@@ -43,16 +43,31 @@ DLReal GetRMSLevel(const DLReal * Sig,const int SigLen)
 		DLReal RMS;
 		int I;
 
-		RMS = (DLReal) 0.0;
-		for (I = 0; I < SigLen; I++)
-			RMS += Sig[I] * Sig[I];
+		/* Variabili di supporto per il Kahan summation algorithm	*/
+		DLReal KC;
+		DLReal KY;
+		DLReal KT;
 
+		/* Calcolo RMS */
+		RMS = (DLReal) 0.0;
+		KC = (DLReal) 0.0;
+		for (I = 0; I < SigLen; I++)
+			{
+				KY = (Sig[I] * Sig[I]) - KC;
+				KT = RMS + KY;
+				KC = (KT - RMS) - KY;
+				RMS = KT;
+			}
+
+		/* Ritorna il valore normalizzato */
 		return (DLReal) sqrt(RMS);
 	}
 
-/* Calola il valore RMS del segnale Sig sulla banda di frequenze indicate */
+/* Calola il valore RMS del segnale Sig sulla banda di frequenze indicate
+con pesatura in frequenza pari a 1/(f^w). Per W = 0 calcola il normale
+valore RMS, per W = 1 assegna peso uguale in potenza per ottava/decade. */
 DLReal GetBLRMSLevel(const DLReal * Sig,const int SigLen,const int SampleFreq,
-	const DLReal StartFreq, const DLReal EndFreq,const int MExp)
+	const DLReal StartFreq,const DLReal EndFreq,const DLReal W,const int MExp)
 	{
 		DLReal RMS;
 		int I;
@@ -84,7 +99,7 @@ DLReal GetBLRMSLevel(const DLReal * Sig,const int SigLen,const int SampleFreq,
 		Fft(FFTArray,FFTSize);
 
 		/* Calcola il valore RMS sulla banda interessata */
-		RMS = GetBLFFTRMSLevel(FFTArray,FFTSize,SampleFreq,StartFreq,EndFreq);
+		RMS = GetBLFFTRMSLevel(FFTArray,FFTSize,SampleFreq,StartFreq,EndFreq,W);
 
 		/* Dealloca l'array FFT */
 		delete FFTArray;
@@ -93,31 +108,111 @@ DLReal GetBLRMSLevel(const DLReal * Sig,const int SigLen,const int SampleFreq,
 		return RMS;
 	}
 
-/* Calola il valore RMS del segnale trasformato FFTArray sulla banda di frequenze indicate */
+/* EulerMascheroni constant */
+#define RMSEMC (0.57721566490153286060651209008240243104215933593992)
+
+/* Limite calcolo diretto */
+#define RMSHNL (256)
+
+/* Calola il valore RMS del segnale trasformato FFTArray sulla banda di frequenze
+indicate con pesatura in frequenza pari a 1/(f^w). Per W = 0 calcola il normale
+valore RMS, per W = 1 assegna peso uguale in potenza per ottava/decade. */
 DLReal GetBLFFTRMSLevel(const DLComplex * FFTArray,const int FFTSize,const int SampleFreq,
-	const DLReal StartFreq, const DLReal EndFreq)
+	const DLReal StartFreq,const DLReal EndFreq,const DLReal W)
 	{
 		DLReal RMS;
 		int I;
 		int FS;
 		int FE;
+		int HS;
+
+		/* Fattore di compensazione per pesatura */
+		DLReal CF;
+
+		/* Variabili di supporto per il Kahan summation algorithm
+		nel calcolo del fattore di compensazione */
+		DLReal KC;
+		DLReal KY;
+		DLReal KT;
 
 		/* Determina gli indici per il calcolo del valore RMS */
-		FS = (int) floor(((FFTSize * StartFreq) / SampleFreq));
-		FE = (int) floor(((FFTSize * EndFreq) / SampleFreq));
+		FS = (int) floor(0.5 + ((FFTSize * StartFreq) / SampleFreq));
+		FE = (int) floor(0.5 + ((FFTSize * EndFreq) / SampleFreq));
+		HS = FFTSize / 2;
 
 		/* Calcola il livello RMS */
-		if (FS > 0)
-			RMS = (DLReal) 0.0;
+		if (W == ((DLReal) 0.0))
+			{
+				/* Valore iniziale */
+				if (FS > 0)
+					RMS = (DLReal) 0.0;
+				else
+					{
+						RMS = std::real(FFTArray[0]) * std::real(FFTArray[0]);
+						FS = 1;
+					}
+
+				/* Calcolo RMS */
+				KC = (DLReal) 0.0;
+				for (I = FS;I < FE;I++)
+					{
+						KY = std::norm(FFTArray[I]) - KC;
+						KT = RMS + KY;
+						KC = (KT - RMS) - KY;
+						RMS = KT;
+					}
+
+				return (DLReal) sqrt(2.0 * RMS / FFTSize);
+			}
 		else
 			{
-				RMS = std::real(FFTArray[0]) * std::real(FFTArray[0]);
-				FS = 1;
-			}
-		for (I = FS;I < FE;I++)
-			RMS += std::norm(FFTArray[I]);
+				/* Valore iniziale */
+				if (FS > 0)
+					{
+						/* Nessuna componente DC */
+						CF = (DLReal) 0.0;
+						RMS = (DLReal) 0.0;
+					}
+				else
+					{
+						/* Assume che la componente DC abbia lo stesso peso della prima
+						componente utile */
+						CF = (DLReal) 1.0;
+						RMS = CF * std::real(FFTArray[0]) * std::real(FFTArray[0]);
+						FS = 1;
+					}
 
-		return (DLReal) sqrt(2.0 * RMS / FFTSize);
+				/* Calcolo RMS */
+				KC = ((DLReal) 0.0);
+				for (I = FS;I < FE;I++)
+					{
+						KY = (std::norm(FFTArray[I]) * ((DLReal) pow(I,-W))) - KC;
+						KT = RMS + KY;
+						KC = (KT - RMS) - KY;
+						RMS = KT;
+					}
+
+				/* Calcola il fattore di normalizzazione, pari al numero armonico */
+				if (HS < RMSHNL)
+					{
+						/* Error > 1e-16, harmonic number direct computation */
+						KC = ((DLReal) 0.0);
+						for (I = HS;I > 0;I--)
+							{
+								KY = ((DLReal) pow(I,-W)) - KC;
+								KT = CF + KY;
+								KC = (KT - CF) - KY;
+								CF = KT;
+							}
+					}
+				else
+					{
+						/* Error < 1e-16, harmonic number approximation */
+						CF += (DLReal) (RMSEMC + log(HS) + 1.0 / (2 * HS) - 1.0 / (12.0 * HS * HS) + 1.0 / (120.0 * pow(HS,4.0)));
+					}
+
+				return (DLReal) sqrt(RMS / CF);
+			}
 	}
 
 
@@ -210,7 +305,7 @@ Boolean SigNormalize(DLReal * Sig,const int SigLen,const DLReal NormFactor,
 
 /* Limitazione valli a fase lineare con calcolo del valore RMS sull banda indicata */
 Boolean LPDipLimit(DLReal * Sig,const int SigLen,const DLReal MinGain,const DLReal DLStart,
-	const int SampleFreq, const DLReal StartFreq, const DLReal EndFreq, const int MExp)
+	const int SampleFreq,const DLReal StartFreq,const DLReal EndFreq,const DLReal W,const int MExp)
 	{
 		int FFTSize;
 		int I;
@@ -249,7 +344,10 @@ Boolean LPDipLimit(DLReal * Sig,const int SigLen,const DLReal MinGain,const DLRe
 		Fft(FFTArray,FFTSize);
 
 		/* Determina il livello RMS del segnale */
-		RMSLevel = MinGain * GetBLFFTRMSLevel(FFTArray,FFTSize,SampleFreq,StartFreq,EndFreq);
+		RMSLevel = GetBLFFTRMSLevel(FFTArray,FFTSize,SampleFreq,StartFreq,EndFreq,W);
+
+		/* Calcola il livello minimo tenendo conto delle limitazioni di banda */
+		RMSLevel = (DLReal) (RMSLevel * MinGain / sqrt(2.0 * (EndFreq - StartFreq) / SampleFreq));
 
 		/* Verifica il tipo di limitazione impostata */
 		if (DLStart >= (DLReal) 1.0)
@@ -324,7 +422,7 @@ Boolean LPDipLimit(DLReal * Sig,const int SigLen,const DLReal MinGain,const DLRe
 /* Limitazione valli a fase lineare con calcolo del valore RMS sulla banda indicata */
 /* Versione con mantenimento continuit della derivata prima nei punti di limitazione */
 Boolean C1LPDipLimit(DLReal * Sig,const int SigLen,const DLReal MinGain,const DLReal DLStart,
-	const int SampleFreq, const DLReal StartFreq, const DLReal EndFreq, const int MExp)
+	const int SampleFreq,const DLReal StartFreq,const DLReal EndFreq,const DLReal W,const int MExp)
 	{
 		int FFTSize;
 		int I;
@@ -360,7 +458,10 @@ Boolean C1LPDipLimit(DLReal * Sig,const int SigLen,const DLReal MinGain,const DL
 		Fft(FFTArray,FFTSize);
 
 		/* Determina il livello RMS del segnale */
-		RMSLevel = MinGain * GetBLFFTRMSLevel(FFTArray,FFTSize,SampleFreq,StartFreq,EndFreq);
+		RMSLevel = GetBLFFTRMSLevel(FFTArray,FFTSize,SampleFreq,StartFreq,EndFreq,W);
+
+		/* Calcola il livello minimo tenendo conto delle limitazioni di banda */
+		RMSLevel = (DLReal) (RMSLevel * MinGain / sqrt(2.0 * (EndFreq - StartFreq) / SampleFreq));
 
 		/* Verifica il tipo di limitazione impostata */
 		if (DLStart >= (DLReal) 1.0)
@@ -411,7 +512,7 @@ Boolean C1LPDipLimit(DLReal * Sig,const int SigLen,const DLReal MinGain,const DL
 /* Limitazione valli a fase minima con calcolo del valore RMS sulla banda indicata */
 /* Versione basata sulla trasformata di Hilbert */
 Boolean HMPDipLimit(DLReal * Sig,const int SigLen,const DLReal MinGain,const DLReal DLStart,
-	const int SampleFreq, const DLReal StartFreq, const DLReal EndFreq, const int MExp)
+	const int SampleFreq,const DLReal StartFreq,const DLReal EndFreq,const DLReal W,const int MExp)
 	{
 		DLComplex * FFTArray1;
 		DLComplex * FFTArray2;
@@ -458,7 +559,10 @@ Boolean HMPDipLimit(DLReal * Sig,const int SigLen,const DLReal MinGain,const DLR
 		Fft(FFTArray1,FS);
 
 		/* Determina il livello RMS del segnale */
-		RMSLevel = MinGain * GetBLFFTRMSLevel(FFTArray1,FS,SampleFreq,StartFreq,EndFreq);
+		RMSLevel = GetBLFFTRMSLevel(FFTArray1,FS,SampleFreq,StartFreq,EndFreq,W);
+
+		/* Calcola il livello minimo tenendo conto delle limitazioni di banda */
+		RMSLevel = (DLReal) (RMSLevel * MinGain / sqrt(2.0 * (EndFreq - StartFreq) / SampleFreq));
 
 		/* Verifica il tipo di limitazione impostata */
 		if (DLStart >= (DLReal) 1.0)
@@ -584,7 +688,7 @@ Boolean HMPDipLimit(DLReal * Sig,const int SigLen,const DLReal MinGain,const DLR
 /* Versione basata sulla trasformata di Hilbert */
 /* Versione con mantenimento continuit della derivata prima nei punti di limitazione */
 Boolean C1HMPDipLimit(DLReal * Sig,const int SigLen,const DLReal MinGain,const DLReal DLStart,
-	const int SampleFreq, const DLReal StartFreq, const DLReal EndFreq, const int MExp)
+	const int SampleFreq,const DLReal StartFreq,const DLReal EndFreq,const DLReal W,const int MExp)
 	{
 		DLComplex * FFTArray1;
 		DLComplex * FFTArray2;
@@ -628,7 +732,10 @@ Boolean C1HMPDipLimit(DLReal * Sig,const int SigLen,const DLReal MinGain,const D
 		Fft(FFTArray1,FS);
 
 		/* Determina il livello RMS del segnale */
-		RMSLevel = MinGain * GetBLFFTRMSLevel(FFTArray1,FS,SampleFreq,StartFreq,EndFreq);
+		RMSLevel = GetBLFFTRMSLevel(FFTArray1,FS,SampleFreq,StartFreq,EndFreq,W);
+
+		/* Calcola il livello minimo tenendo conto delle limitazioni di banda */
+		RMSLevel = (DLReal) (RMSLevel * MinGain / sqrt(2.0 * (EndFreq - StartFreq) / SampleFreq));
 
 		/* Verifica il tipo di limitazione impostata */
 		if (DLStart >= (DLReal) 1.0)
@@ -729,7 +836,7 @@ Boolean C1HMPDipLimit(DLReal * Sig,const int SigLen,const DLReal MinGain,const D
 
 /* Limitazione picchi a fase lineare con calcolo del valore RMS sull banda indicata */
 Boolean LPPeakLimit(DLReal * Sig,const int SigLen,const DLReal MaxGain,const DLReal PLStart,
-	const int SampleFreq, const DLReal StartFreq, const DLReal EndFreq, const int MExp)
+	const int SampleFreq,const DLReal StartFreq,const DLReal EndFreq,const DLReal W,const int MExp)
 	{
 		int FFTSize;
 		int I;
@@ -768,7 +875,10 @@ Boolean LPPeakLimit(DLReal * Sig,const int SigLen,const DLReal MaxGain,const DLR
 		Fft(FFTArray,FFTSize);
 
 		/* Determina il livello RMS del segnale */
-		RMSLevel = MaxGain * GetBLFFTRMSLevel(FFTArray,FFTSize,SampleFreq,StartFreq,EndFreq);
+		RMSLevel = GetBLFFTRMSLevel(FFTArray,FFTSize,SampleFreq,StartFreq,EndFreq,W);
+
+		/* Calcola il livello massimo tenendo conto delle limitazioni di banda */
+		RMSLevel = (DLReal) (RMSLevel * MaxGain / sqrt(2.0 * (EndFreq - StartFreq) / SampleFreq));
 
 		/* Verifica il tipo di limitazione impostata */
 		if (PLStart >= (DLReal) 1.0)
@@ -843,7 +953,7 @@ Boolean LPPeakLimit(DLReal * Sig,const int SigLen,const DLReal MaxGain,const DLR
 /* Limitazione picchi a fase lineare con calcolo del valore RMS sull banda indicata */
 /* Versione con mantenimento continuit della derivata prima nei punti di limitazione */
 Boolean C1LPPeakLimit(DLReal * Sig,const int SigLen,const DLReal MaxGain,const DLReal PLStart,
-	const int SampleFreq, const DLReal StartFreq, const DLReal EndFreq, const int MExp)
+	const int SampleFreq,const DLReal StartFreq,const DLReal EndFreq,const DLReal W,const int MExp)
 	{
 		int FFTSize;
 		int I;
@@ -879,7 +989,10 @@ Boolean C1LPPeakLimit(DLReal * Sig,const int SigLen,const DLReal MaxGain,const D
 		Fft(FFTArray,FFTSize);
 
 		/* Determina il livello RMS del segnale */
-		RMSLevel = MaxGain * GetBLFFTRMSLevel(FFTArray,FFTSize,SampleFreq,StartFreq,EndFreq);
+		RMSLevel = GetBLFFTRMSLevel(FFTArray,FFTSize,SampleFreq,StartFreq,EndFreq,W);
+
+		/* Calcola il livello massimo tenendo conto delle limitazioni di banda */
+		RMSLevel = (DLReal) (RMSLevel * MaxGain / sqrt(2.0 * (EndFreq - StartFreq) / SampleFreq));
 
 		/* Verifica il tipo di limitazione impostata */
 		if (PLStart >= (DLReal) 1.0)
@@ -930,7 +1043,7 @@ Boolean C1LPPeakLimit(DLReal * Sig,const int SigLen,const DLReal MaxGain,const D
 /* Limitazione picchi a fase minima con calcolo del valore RMS sull banda indicata */
 /* Versione basata sulla trasformata di Hilbert */
 Boolean HMPPeakLimit(DLReal * Sig,const int SigLen,const DLReal MaxGain,const DLReal PLStart,
-	const int SampleFreq, const DLReal StartFreq, const DLReal EndFreq, const int MExp)
+	const int SampleFreq,const DLReal StartFreq,const DLReal EndFreq,const DLReal W,const int MExp)
 	{
 		DLComplex * FFTArray1;
 		DLComplex * FFTArray2;
@@ -977,7 +1090,10 @@ Boolean HMPPeakLimit(DLReal * Sig,const int SigLen,const DLReal MaxGain,const DL
 		Fft(FFTArray1,FS);
 
 		/* Determina il livello RMS del segnale */
-		RMSLevel = MaxGain  * GetBLFFTRMSLevel(FFTArray1,FS,SampleFreq,StartFreq,EndFreq);
+		RMSLevel = GetBLFFTRMSLevel(FFTArray1,FS,SampleFreq,StartFreq,EndFreq,W);
+
+		/* Calcola il livello massimo tenendo conto delle limitazioni di banda */
+		RMSLevel = (DLReal) (RMSLevel * MaxGain / sqrt(2.0 * (EndFreq - StartFreq) / SampleFreq));
 
 		/* Verifica il tipo di limitazione impostata */
 		if (PLStart >= (DLReal) 1.0)
@@ -1103,7 +1219,7 @@ Boolean HMPPeakLimit(DLReal * Sig,const int SigLen,const DLReal MaxGain,const DL
 /* Versione basata sulla trasformata di Hilbert */
 /* Versione con mantenimento continuit della derivata prima nei punti di limitazione */
 Boolean C1HMPPeakLimit(DLReal * Sig,const int SigLen,const DLReal MaxGain,const DLReal PLStart,
-	const int SampleFreq, const DLReal StartFreq, const DLReal EndFreq, const int MExp)
+	const int SampleFreq,const DLReal StartFreq,const DLReal EndFreq,const DLReal W,const int MExp)
 	{
 		DLComplex * FFTArray1;
 		DLComplex * FFTArray2;
@@ -1147,7 +1263,10 @@ Boolean C1HMPPeakLimit(DLReal * Sig,const int SigLen,const DLReal MaxGain,const
 		Fft(FFTArray1,FS);
 
 		/* Determina il livello RMS del segnale */
-		RMSLevel = MaxGain  * GetBLFFTRMSLevel(FFTArray1,FS,SampleFreq,StartFreq,EndFreq);
+		RMSLevel = GetBLFFTRMSLevel(FFTArray1,FS,SampleFreq,StartFreq,EndFreq,W);
+
+		/* Calcola il livello massimo tenendo conto delle limitazioni di banda */
+		RMSLevel = (DLReal) (RMSLevel * MaxGain / sqrt(2.0 * (EndFreq - StartFreq) / SampleFreq));
 
 		/* Verifica il tipo di limitazione impostata */
 		if (PLStart >= (DLReal) 1.0)
