@@ -39,13 +39,17 @@
 	/* Calola il valore RMS del segnale Sig */
 	DLReal GetRMSLevel(const DLReal * Sig,const int SigLen);
 
-	/* Calola il valore RMS del segnale Sig sulla banda di frequenze indicate */
+	/* Calola il valore RMS del segnale Sig sulla banda di frequenze indicate
+	con pesatura in frequenza pari a 1/(f^w). Per W = 0 calcola il normale
+	valore RMS, per W = 1 assegna peso uguale in potenza per ottava/decade. */
 	DLReal GetBLRMSLevel(const DLReal * Sig,const int SigLen,const int SampleFreq,
-		const DLReal StartFreq, const DLReal EndFreq,const int MExp);
+		const DLReal StartFreq,const DLReal EndFreq,const DLReal W,const int MExp);
 
-	/* Calola il valore RMS del segnale trasformato FFTArray sulla banda di frequenze indicate */
+	/* Calola il valore RMS del segnale trasformato FFTArray sulla banda di frequenze
+	indicate con pesatura in frequenza pari a 1/(f^w). Per W = 0 calcola il normale
+	valore RMS, per W = 1 assegna peso uguale in potenza per ottava/decade. */
 	DLReal GetBLFFTRMSLevel(const DLComplex * FFTArray,const int FFTSize,const int SampleFreq,
-		const DLReal StartFreq, const DLReal EndFreq);
+		const DLReal StartFreq,const DLReal EndFreq,const DLReal W);
 
 	/* Tipi normalizzazione */
 	typedef enum { NormMax = 'M', NormSum = 'S',
@@ -58,43 +62,43 @@
 
 	/* Limitazione valli a fase lineare con calcolo del valore RMS sull banda indicata */
 	Boolean LPDipLimit(DLReal * Sig,const int SigLen,const DLReal MinGain,const DLReal DLStart,
-		const int SampleFreq, const DLReal StartFreq, const DLReal EndFreq, const int MExp);
+		const int SampleFreq,const DLReal StartFreq,const DLReal EndFreq,const DLReal W,const int MExp);
 
 	/* Limitazione valli a fase lineare con calcolo del valore RMS sull banda indicata */
 	/* Versione con mantenimento continuit della derivata prima nei punti di limitazione */
 	Boolean C1LPDipLimit(DLReal * Sig,const int SigLen,const DLReal MinGain,const DLReal DLStart,
-		const int SampleFreq, const DLReal StartFreq, const DLReal EndFreq, const int MExp);
+		const int SampleFreq,const DLReal StartFreq,const DLReal EndFreq,const DLReal W,const int MExp);
 
 	/* Limitazione valli a fase minima con calcolo del valore RMS sull banda indicata */
 	/* Versione basata sulla trasformata di Hilbert */
 	Boolean HMPDipLimit(DLReal * Sig,const int SigLen,const DLReal MinGain,const DLReal DLStart,
-		const int SampleFreq, const DLReal StartFreq, const DLReal EndFreq, const int MExp);
+		const int SampleFreq,const DLReal StartFreq,const DLReal EndFreq,const DLReal W,const int MExp);
 
 	/* Limitazione valli a fase minima con calcolo del valore RMS sull banda indicata */
 	/* Versione basata sulla trasformata di Hilbert */
 	/* Versione con mantenimento continuit della derivata prima nei punti di limitazione */
 	Boolean C1HMPDipLimit(DLReal * Sig,const int SigLen,const DLReal MinGain,const DLReal DLStart,
-		const int SampleFreq, const DLReal StartFreq, const DLReal EndFreq, const int MExp);
+		const int SampleFreq,const DLReal StartFreq,const DLReal EndFreq,const DLReal W,const int MExp);
 
 	/* Limitazione picchi a fase lineare con calcolo del valore RMS sull banda indicata */
 	Boolean LPPeakLimit(DLReal * Sig,const int SigLen,const DLReal MaxGain,const DLReal PLStart,
-		const int SampleFreq, const DLReal StartFreq, const DLReal EndFreq, const int MExp);
+		const int SampleFreq,const DLReal StartFreq,const DLReal EndFreq,const DLReal W,const int MExp);
 
 	/* Limitazione picchi a fase lineare con calcolo del valore RMS sull banda indicata */
 	/* Versione con mantenimento continuit della derivata prima nei punti di limitazione */
 	Boolean C1LPPeakLimit(DLReal * Sig,const int SigLen,const DLReal MaxGain,const DLReal PLStart,
-		const int SampleFreq, const DLReal StartFreq, const DLReal EndFreq, const int MExp);
+		const int SampleFreq,const DLReal StartFreq,const DLReal EndFreq,const DLReal W,const int MExp);
 
 	/* Limitazione picchi a fase minima con calcolo del valore RMS sull banda indicata */
 	/* Versione basata sulla trasformata di Hilbert */
 	Boolean HMPPeakLimit(DLReal * Sig,const int SigLen,const DLReal MaxGain,const DLReal PLStart,
-		const int SampleFreq, const DLReal StartFreq, const DLReal EndFreq, const int MExp);
+		const int SampleFreq,const DLReal StartFreq,const DLReal EndFreq,const DLReal W,const int MExp);
 
 	/* Limitazione picchi a fase minima con calcolo del valore RMS sull banda indicata */
 	/* Versione basata sulla trasformata di Hilbert */
 	/* Versione con mantenimento continuit della derivata prima nei punti di limitazione */
 	Boolean C1HMPPeakLimit(DLReal * Sig,const int SigLen,const DLReal MaxGain,const DLReal PLStart,
-		const int SampleFreq, const DLReal StartFreq, const DLReal EndFreq, const int MExp);
+		const int SampleFreq,const DLReal StartFreq,const DLReal EndFreq,const DLReal W,const int MExp);
 
 	/* Livellazione norma a fase lineare */
 	Boolean LPNormFlat(DLReal * Sig,const int SigLen,const DLReal Gain,const DLReal OGainFactor,const int MExp);
