@@ -1,22 +1,21 @@
 /****************************************************************************
 
     DRC: Digital Room Correction
-    Copyright (C) 2002 Denis Sbragion
+    Copyright (C) 2002-2010 Denis Sbragion
 
-		This file is part of DRC, Digital Room Correction
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
 
-		DRC  is  distributed  with  NO WARRANTY OF ANY KIND. No author or
-		distributor accepts any responsibility for  the  consequences  of
-		using  it,  or  for  whether  it serves any particular purpose or
-		works at all, unless he or she says so in writing.  Refer to  the
-		Aladdin Free Public License (the "License") for full details.
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
 
-		Every copy of DRC must include a copy of the License, normally in
-		a plain ASCII text file named PUBLIC. The License grants you  the
-		right  to  copy, modify and redistribute DRC, but only under cer
-		tain conditions described in the License.   Among  other  things,
-		the License requires that the copyright notice and this notice be
-		preserved on all copies.
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 		You can contact the author on Internet at the following address:
 
@@ -27,6 +26,10 @@
 		secfg.h files.  Many thanks to Yuuki NINOMIYA for this useful li
 		brary.
 
+		This program uses  also the FFT  routines from  Takuya Ooura and
+		the GNU Scientific  Library (GSL).  Many thanks  to Takuya Ooura
+		and the GSL developers for these efficient routines.
+
 ****************************************************************************/
 
 /* Spline routines */
